==> open-xchange-guard_2.4.2.orig.tar.bz2: open-xchange-guard-2.4.2/com.openexchange.guard.common/src/com/openexchange/guard/exceptions/GuardCoreExceptionCodes.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.exceptions;

import com.openexchange.exception.Category;
import com.openexchange.exception.DisplayableOXExceptionCode;
import com.openexchange.exception.OXException;
import com.openexchange.exception.OXExceptionFactory;
import com.openexchange.exception.OXExceptionStrings;

/**
 *
 * Exception codes for guard core purposes.
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since 2.4.0
 */
public enum GuardCoreExceptionCodes implements DisplayableOXExceptionCode {

    SQL_ERROR("An SQL error occurred: %1$s", CATEGORY_ERROR, 1),

    PARAMETER_MISSING("The parameter \"%1$s\" is missing.", Category.CATEGORY_ERROR, 2),

    JSON_PARAMETER_MISSING("The parameter \"%1$s\" is missing in provided JSON.", Category.CATEGORY_ERROR, 3),

    CONFIGURATION_ERROR("\"%1$s\" not configured correctly: \"%2$s\"", Category.CATEGORY_ERROR, 4),

    /** An error occurred: %1$s */
    UNEXPECTED_ERROR("An error occurred: %1$s", Category.CATEGORY_ERROR, 5),

    /** An I/O error occurred: %1$s */
    IO_ERROR("An I/O error occurred: %1$s", Category.CATEGORY_ERROR, 6),

    KEY_NOT_FOUND_FOR_MAIL_ERROR("Could not find key for email \"%1$s\" in context %2$d", Category.CATEGORY_ERROR, 7),

    KEY_NOT_FOUND_FOR_IDS_ERROR("Could not find key for user with id \"%1$d\" in context %2$d", Category.CATEGORY_ERROR, 8),

    KEY_NOT_FOUND_FOR_KEY_ID_ERROR("Could not find key for key id \"%1$s\"", Category.CATEGORY_ERROR, 9),

    JSON_ERROR("Error while processing provided JSON: %1$s.", Category.CATEGORY_ERROR, 10),

    DISABLED_ERROR("Failed to %1$s because this is disabled per configuration.", CATEGORY_ERROR, 11),

    ;

    private final String message;
    private final String displayMessage;
    private final Category category;
    private final int number;

    /**
     * Default constructor.
     *
     * @param message message.
     * @param category category.
     * @param number detail number.
     */
    private GuardCoreExceptionCodes(String message, Category category, int number) {
        this(message, null, category, number);
    }

    private GuardCoreExceptionCodes(String message, String displayMessage, Category category, int number) {
        this.message = message;
        this.displayMessage = displayMessage != null ? displayMessage : OXExceptionStrings.MESSAGE;
        this.category = category;
        this.number = number;
    }

    @Override
    public String getPrefix() {
        return "GRD-CORE";
    }

    /**
     * @return the message
     */
    @Override
    public String getMessage() {
        return message;
    }

    @Override
    public String getDisplayMessage() {
        return displayMessage;
    }

    /**
     * @return the category
     */
    @Override
    public Category getCategory() {
        return category;
    }

    /**
     * @return the number
     */
    @Override
    public int getNumber() {
        return number;
    }

    @Override
    public boolean equals(final OXException e) {
        return OXExceptionFactory.getInstance().equals(this, e);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @return The newly created {@link OXException} instance
     */
    public OXException create() {
        return OXExceptionFactory.getInstance().create(this, new Object[0]);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(final Object... args) {
        return OXExceptionFactory.getInstance().create(this, (Throwable) null, args);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param cause The optional initial cause
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(final Throwable cause, final Object... args) {
        return OXExceptionFactory.getInstance().create(this, cause, args);
    }
}

==> open-xchange-guard_2.6.0.orig.tar.bz2: open-xchange-guard-2.6.0/com.openexchange.guard.common/src/com/openexchange/guard/exceptions/GuardCoreExceptionCodes.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.exceptions;

import com.openexchange.exception.Category;
import com.openexchange.exception.DisplayableOXExceptionCode;
import com.openexchange.exception.OXException;
import com.openexchange.exception.OXExceptionFactory;
import com.openexchange.exception.OXExceptionStrings;

/**
 *
 * Exception codes for guard core purposes.
 *
 * @author <a href="mailto:martin.schneider@open-xchange.com">Martin Schneider</a>
 * @since 2.4.0
 */
public enum GuardCoreExceptionCodes implements DisplayableOXExceptionCode {

    SQL_ERROR("An SQL error occurred: %1$s", CATEGORY_ERROR, 1),

    PARAMETER_MISSING("The parameter \"%1$s\" is missing.", Category.CATEGORY_ERROR, 2),

    JSON_PARAMETER_MISSING("The parameter \"%1$s\" is missing in provided JSON.", Category.CATEGORY_ERROR, 3),

    CONFIGURATION_ERROR("\"%1$s\" not configured correctly: \"%2$s\"", Category.CATEGORY_ERROR, 4),

    /** An error occurred: %1$s */
    UNEXPECTED_ERROR("An error occurred: %1$s", Category.CATEGORY_ERROR, 5),

    /** An I/O error occurred: %1$s */
    IO_ERROR("An I/O error occurred: %1$s", Category.CATEGORY_ERROR, 6),

    KEY_NOT_FOUND_FOR_MAIL_ERROR("Could not find key for email \"%1$s\" in context %2$d", Category.CATEGORY_ERROR, 7),

    KEY_NOT_FOUND_FOR_IDS_ERROR("Could not find key for user with id \"%1$d\" in context %2$d", Category.CATEGORY_ERROR, 8),

    KEY_NOT_FOUND_FOR_KEY_ID_ERROR("Could not find key for key id \"%1$s\"", Category.CATEGORY_ERROR, 9),

    JSON_ERROR("Error while processing provided JSON: %1$s.", Category.CATEGORY_ERROR, 10),

    DISABLED_ERROR("Failed to %1$s because this is disabled per configuration.", CATEGORY_ERROR, 11),

    KEY_NOT_FOUND("The requested key was not found", CATEGORY_ERROR, 12),

    NOT_A_GUEST_ACCOUNT("The requested account is not a valid guest account", CATEGORY_ERROR, 13),

    PARAMETER_MISMATCH("The parameters \"%1$s\" and \"%2$s\" cannot be specified at the same time", CATEGORY_ERROR,14),

    INVALID_PARAMETER_VALUE("The parameter \"%1$s\" does not contain a valid value", CATEGORY_ERROR,15),

    MULTIPART_UPLOAD_MISSING("Missing multipart/form-data", CATEGORY_ERROR, 16),

    MULTIPART_UPLOAD_ERROR("Error parsing multipart/form-data: %1$s", CATEGORY_ERROR, 17);

    ;

    private final String message;
    private final String displayMessage;
    private final Category category;
    private final int number;

    /**
     * Default constructor.
     *
     * @param message message.
     * @param category category.
     * @param number detail number.
     */
    private GuardCoreExceptionCodes(String message, Category category, int number) {
        this(message, null, category, number);
    }

    private GuardCoreExceptionCodes(String message, String displayMessage, Category category, int number) {
        this.message = message;
        this.displayMessage = displayMessage != null ? displayMessage : OXExceptionStrings.MESSAGE;
        this.category = category;
        this.number = number;
    }

    @Override
    public String getPrefix() {
        return "GRD-CORE";
    }

    /**
     * @return the message
     */
    @Override
    public String getMessage() {
        return message;
    }

    @Override
    public String getDisplayMessage() {
        return displayMessage;
    }

    /**
     * @return the category
     */
    @Override
    public Category getCategory() {
        return category;
    }

    /**
     * @return the number
     */
    @Override
    public int getNumber() {
        return number;
    }

    @Override
    public boolean equals(final OXException e) {
        return OXExceptionFactory.getInstance().equals(this, e);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @return The newly created {@link OXException} instance
     */
    public OXException create() {
        return OXExceptionFactory.getInstance().create(this, new Object[0]);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(final Object... args) {
        return OXExceptionFactory.getInstance().create(this, (Throwable) null, args);
    }

    /**
     * Creates a new {@link OXException} instance pre-filled with this code's attributes.
     *
     * @param cause The optional initial cause
     * @param args The message arguments in case of printf-style message
     * @return The newly created {@link OXException} instance
     */
    public OXException create(final Throwable cause, final Object... args) {
        return OXExceptionFactory.getInstance().create(this, cause, args);
    }
}
